@@ -65,6 +65,9 @@ api <- function(user_key, endpoint, parameters=FALSE, custom_headers=NULL, url_p
       "tokens"= error_check(
         post_endpoint(user_key, check_content_parameters(parameters), "tokens", url, custom_headers, url_parameters)
       ),
+      "topics"= error_check(
+        post_endpoint(user_key, check_content_parameters(parameters), "topics", url, custom_headers, url_parameters)
+      ),
       "morphology"= error_check(
         post_endpoint(user_key, check_content_parameters(parameters), check_morphology(parameters, "morphology"), url, custom_headers, url_parameters)
       ),
@@ -93,7 +96,7 @@ api <- function(user_key, endpoint, parameters=FALSE, custom_headers=NULL, url_p
 #' Provides the binding Version
 #' @return current binding version
 get_binding_version <- function() {
-  bindingVersion <- "1.5.0"
+  bindingVersion <- "1.8.0"
   return(bindingVersion)
 }
 
@@ -152,8 +155,6 @@ check_deduplication <- function(parameters, endpoint) {
   params <- parameters
   if (!("names" %in% names(params))) {
     stop("Must supply a list of names to deduplicate")
-  } else if (!("threshold" %in% names(params))) {
-    parameters[[ "threshold" ]] <- 0.75
   } else {
     return(parameters)
   }
